summaryrefslogtreecommitdiffstats
path: root/Source/cmLocalUnixMakefileGenerator3.h
diff options
context:
space:
mode:
authorKen Martin <ken.martin@kitware.com>2005-10-19 14:03:20 (GMT)
committerKen Martin <ken.martin@kitware.com>2005-10-19 14:03:20 (GMT)
commit6b444ee345e7dcabbac33a18ba8e4c16fd7a7b54 (patch)
treeeb5916428f4d7180749e06f0626b3726a339ab50 /Source/cmLocalUnixMakefileGenerator3.h
parent66e50573c15d7338868142d7f1055c3491048291 (diff)
downloadCMake-6b444ee345e7dcabbac33a18ba8e4c16fd7a7b54.zip
CMake-6b444ee345e7dcabbac33a18ba8e4c16fd7a7b54.tar.gz
CMake-6b444ee345e7dcabbac33a18ba8e4c16fd7a7b54.tar.bz2
BUG: cd into local directory to reduce link line length
Diffstat (limited to 'Source/cmLocalUnixMakefileGenerator3.h')
-rw-r--r--Source/cmLocalUnixMakefileGenerator3.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/Source/cmLocalUnixMakefileGenerator3.h b/Source/cmLocalUnixMakefileGenerator3.h
index ea70e6a..466cf50 100644
--- a/Source/cmLocalUnixMakefileGenerator3.h
+++ b/Source/cmLocalUnixMakefileGenerator3.h
@@ -170,8 +170,11 @@ protected:
const char *MakefileName,
std::string & localName);
- // these two methods just compute reasonable values for m_LibraryOutputPath and
- // m_ExecutableOutputPath
+ // create a command that cds to the start dir then runs the commands
+ void CreateCDCommand(std::vector<std::string>& commands);
+
+ // these two methods just compute reasonable values for m_LibraryOutputPath
+ // and m_ExecutableOutputPath
void ConfigureOutputPaths();
void FormatOutputPath(std::string& path, const char* name);